@@ -8,7 +8,7 @@ __docformat__ = "google"
 import logging
 import os
 from pathlib import Path
-from typing import Any, Dict, Union
+from typing import Any, Dict, List, Optional, Union
 
 _DATACLASSES_TYPES: Dict[str, type] = {}
 
@@ -16,8 +16,10 @@ _DATACLASSES_TYPES: Dict[str, type] = {}
 _ENVIRONMENT: Dict[str, Any] = {
     "TB_ARTIFACT_PATH": Path("./"),
     "TB_KERAS_FORMAT": "tf",
-    "TB_PANDAS_FORMAT": "h5",
     "TB_MAX_NBYTES": 8_000,
+    "TB_NODECODE": [],
+    "TB_PANDAS_FORMAT": "h5",
+    "TB_SHARED_KEY": None,
 }
 
 
@@ -71,6 +73,9 @@ def _init():
             _ENVIRONMENT["TB_PANDAS_FORMAT"],
         )
 
+    if "TB_NODECODE" in os.environ:
+        set_nodecode(os.environ["TB_NODECODE"])
+
     if "TB_NUMPY_MAX_NBYTES" in os.environ:
         logging.warning(
             "The use of the TB_NUMPY_MAX_NBYTES environment variable is "
@@ -87,6 +92,9 @@ def _init():
             )
         )
 
+    if "TB_SHARED_KEY" in os.environ:
+        set_shared_key(os.environ["TB_SHARED_KEY"])
+
 
 def get_artifact_path() -> Path:
     return _ENVIRONMENT["TB_ARTIFACT_PATH"]
@@ -108,6 +116,14 @@ def get_registered_dataclass(name: str) -> type:
     return _DATACLASSES_TYPES[name]
 
 
+def get_shared_key() -> Optional[bytes]:
+    return _ENVIRONMENT["TB_SHARED_KEY"]
+
+
+def is_nodecode(type_name: str) -> bool:
+    return type_name in _ENVIRONMENT["TB_NODECODE"]
+
+
 def register_dataclass(name: str, cls: type):
     """
     Registers a dataclass for dataclass deserialization. Registered types may
@@ -136,6 +152,18 @@ def set_keras_format(fmt: str):
     _ENVIRONMENT["TB_KERAS_FORMAT"] = fmt
 
 
+def set_max_nbytes(nbytes: int):
+    if nbytes <= 0:
+        raise ValueError("numpy's max nbytes must be > 0")
+    _ENVIRONMENT["TB_MAX_NBYTES"] = nbytes
+
+
+def set_nodecode(types: Union[str, List[str]]):
+    _ENVIRONMENT["TB_NODECODE"] = (
+        types.split(",") if isinstance(types, str) else types
+    )
+
+
 def set_pandas_format(fmt: str):
     fmt = fmt.lower()
     PANDAS_FORMATS = [
@@ -157,10 +185,10 @@ def set_pandas_format(fmt: str):
     _ENVIRONMENT["TB_PANDAS_FORMAT"] = fmt
 
 
-def set_max_nbytes(nbytes: int):
-    if nbytes <= 0:
-        raise ValueError("numpy's max nbytes must be > 0")
-    _ENVIRONMENT["TB_MAX_NBYTES"] = nbytes
+def set_shared_key(key: Optional[Union[str, bytes]]):
+    if isinstance(key, str):
+        key = key.encode("utf-8")
+    _ENVIRONMENT["TB_SHARED_KEY"] = key
 
 
 _init()
